/* DisplayManager.m - Menu suppor class to 
   the Display menu functions for the 
   Macintosh OS X SDL port of Atari800
   Mark Grebe <atarimac@cox.net>
   
   Based on the Preferences pane of the
   TextEdit application.

*/
#import "DisplayManager.h"

extern void SwitchFullscreen(void);
extern int requestDoubleSizeChange;
extern int DOUBLESIZE;
extern int SCALE_MODE;
extern int scaleFactor;
extern int requestWidthModeChange;
extern int WIDTH_MODE;
extern int SHOWFPS;
extern int requestFullScreenChange;
extern int requestFpsChange;
extern int requestScaleModeChange;
extern int requestGrabMouse;
extern int requestScreenshot;

/* Functions which provide an interface for C code to call this object's shared Instance functions */
void SetDisplayManagerDoubleSize(int scale) {
    [[DisplayManager sharedInstance] setDoublesizeMenu:scale];
    }

void SetDisplayManagerWidthMode(int widthMode) {
    [[DisplayManager sharedInstance] setWidthmodeMenu:(widthMode)];
    }

void SetDisplayManagerFps(int fpsOn) {
    [[DisplayManager sharedInstance] setFpsMenu:(fpsOn)];
    }

void SetDisplayManagerScaleMode(int scaleMode) {
    [[DisplayManager sharedInstance] setScaleModeMenu:(scaleMode)];
    }

void SetDisplayManagerGrabMouse(int mouseOn) {
    [[DisplayManager sharedInstance] setGrabmouseMenu:(mouseOn)];
    }

@implementation DisplayManager

static DisplayManager *sharedInstance = nil;

+ (DisplayManager *)sharedInstance {
    return sharedInstance ? sharedInstance : [[self alloc] init];
}

- (id)init {
    if (sharedInstance) {
	[self dealloc];
    } else {
        [super init];
        sharedInstance = self;
    }
    return sharedInstance;
}

- (void)dealloc {
}

/*------------------------------------------------------------------------------
*  setDoublesizeMenu - This method is used to set the menu text for the 
*     single/double size menu item.
*-----------------------------------------------------------------------------*/
- (void)setDoublesizeMenu:(int)scale
{
	switch(scale)
	{
		case 1:
			[scale1xItem setState:NSOnState];
			[scale2xItem setState:NSOffState];
			[scale3xItem setState:NSOffState];
			[scale4xItem setState:NSOffState];
			break;
		case 2:
			[scale1xItem setState:NSOffState];
			[scale2xItem setState:NSOnState];
			[scale3xItem setState:NSOffState];
			[scale4xItem setState:NSOffState];
			break;
		case 3:
			[scale1xItem setState:NSOffState];
			[scale2xItem setState:NSOffState];
			[scale3xItem setState:NSOnState];
			[scale4xItem setState:NSOffState];
			break;
		case 4:
			[scale1xItem setState:NSOffState];
			[scale2xItem setState:NSOffState];
			[scale3xItem setState:NSOffState];
			[scale4xItem setState:NSOnState];
			break;
	}
}

/*------------------------------------------------------------------------------
*  setWidthmodeMenu - This method is used to set the menu text for the 
*     short/default/full width menu item.
*-----------------------------------------------------------------------------*/
- (void)setWidthmodeMenu:(int)widthMode
{
	switch(widthMode)
	{
		case 0:
			[widthModeNarrowItem setState:NSOnState];
			[widthModeDefaultItem setState:NSOffState];
			[widthModeFullItem setState:NSOffState];
			break;
		case 1:
			[widthModeNarrowItem setState:NSOffState];
			[widthModeDefaultItem setState:NSOnState];
			[widthModeFullItem setState:NSOffState];
			break;
		case 2:
			[widthModeNarrowItem setState:NSOffState];
			[widthModeDefaultItem setState:NSOffState];
			[widthModeFullItem setState:NSOnState];
			break;
	}

}

/*------------------------------------------------------------------------------
*  setGrabmouseMenu - This method is used to set/clear the enabled check for the 
*     Grab mouse menu item.
*-----------------------------------------------------------------------------*/
- (void)setGrabmouseMenu:(int)mouseOn
{
    if (mouseOn)
        [grabMouseItem setTarget:self];
    else
        [grabMouseItem setTarget:nil];
}

/*------------------------------------------------------------------------------
*  setFpsMenu - This method is used to set/clear the enabled check for the 
*     display frames per second menu item.
*-----------------------------------------------------------------------------*/
- (void)setFpsMenu:(int)fpsOn
{
    if (fpsOn)
        [displayFpsItem setState:NSOnState];
    else
        [displayFpsItem setState:NSOffState];
}

/*------------------------------------------------------------------------------
*  setScaleModeMenu - This method is used to set the menu text for the
*     normal/scanline/smooth scale mode menu item.
*-----------------------------------------------------------------------------*/
- (void)setScaleModeMenu:(int)scaleMode
{
	switch(scaleMode)
	{
		case 0:
			[scaleModeNormalItem setState:NSOnState];
			[scaleModeScanlineItem setState:NSOffState];
			[scaleModeSmoothItem setState:NSOffState];
			break;
		case 1:
			[scaleModeNormalItem setState:NSOffState];
			[scaleModeScanlineItem setState:NSOnState];
			[scaleModeSmoothItem setState:NSOffState];
			break;
		case 2:
			[scaleModeNormalItem setState:NSOffState];
			[scaleModeScanlineItem setState:NSOffState];
			[scaleModeSmoothItem setState:NSOnState];
			break;
	}
}

/*------------------------------------------------------------------------------
*  doubleSize - This method handles the single/double size menu selection.
*-----------------------------------------------------------------------------*/
- (IBAction)doubleSize:(id)sender
{
    requestDoubleSizeChange = [sender tag];
}

/*------------------------------------------------------------------------------
*  fullScreen - This method handles the windowed/fullscreen menu selection.
*-----------------------------------------------------------------------------*/
- (IBAction)fullScreen:(id)sender
{
    requestFullScreenChange = 1;
}

/*------------------------------------------------------------------------------
*  displayFps - This method handles the display frames per second menu 
*     selection.
*-----------------------------------------------------------------------------*/
- (IBAction)displayFps:(id)sender
{
    [self setFpsMenu:(1-SHOWFPS)];
    requestFpsChange = 1;
}

/*------------------------------------------------------------------------------
*  scaleMode - This method handles the normal/scanline/smooth scale mode menu
*       selection.
*-----------------------------------------------------------------------------*/
- (IBAction)scaleMode:(id)sender
{
    requestScaleModeChange = [sender tag];
}

/*------------------------------------------------------------------------------
*  displayFps - This method handles the grab mouse menu selection.
*-----------------------------------------------------------------------------*/
- (IBAction)grabMouse:(id)sender;
{
    requestGrabMouse = 1;
}

/*------------------------------------------------------------------------------
*  screenshot - This method handles the take screenshot menu selection.
*-----------------------------------------------------------------------------*/
- (IBAction)screenshot:(id)sender
{
    requestScreenshot = 1;
}

/*------------------------------------------------------------------------------
*  widthMode - This method handles the short/default/full width mode menu 
*       selection.
*-----------------------------------------------------------------------------*/
- (IBAction)widthMode:(id)sender
{
    requestWidthModeChange = [sender tag];
}

@end
